@@ -9,7 +9,7 @@ GTVERSION=$(gettext --version|head -1|awk '{print$NF}'|sed -r 's,(^[^\.]*\.[^\.]
 if [ -x "`which git 2>/dev/null`" -a -d .git ]; then
 	VERSION=$(git describe --tags|sed 's,[-_],.,g;s,\.g.*$,,')
 	DATE=$(git show -s --format=%ci HEAD^{commit}|awk '{print$1}')
-	MDOCDATE=$(date --date="$DATE" +'%B %d, %Y')
+	MDOCDATE=$(date --date="$DATE" +'%B %-d, %Y')
 	BRANCH=$(git tag --sort=-creatordate|head -1)
 	GNITS="gnits "
 	if [ "$VERSION" != "$BRANCH" ]; then
@@ -41,3 +41,7 @@ fi
 mkdir m4 2>/dev/null
 
 autoreconf -fiv
+
+# cscope target won't work without this
+#
+[ -f po/Makefile.in.in ] && printf '\n%%:\n\t@:\n\n' >> po/Makefile.in.in
